..
    This file is part of Invenio.
    Copyright (C) 2015-2024 CERN.
    Copyright (C) 2024-2025 Graz University of Technology.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version v3.3.1 (released 2025-10-21)

- i18n: pulled translations

Version v3.3.0 (released 2025-07-17)

- i18n: pulled translations

Version 3.2.0 (released 2025-07-01)

- fix: pkg_resources DeprecationWarning

Version 3.1.0 (released 2025-06-10)

- badges: add color URL parameter
- fix: setuptools require underscores instead of dashes
- i18n: removed deprecated messages
- docs: update install instructions

Version 3.0.0 (released 2024-12-05)

- setup: bump major dependencies

Version 2.0.4 (release 2024-11-30)

- setup: change to reusable workflows
- setup: pin dependencies
- i18n:push translations

Version 2.0.3 (released 2024-04-02)

- escaped badge title and value on svg generation

Version 2.0.2 (released 2024-02-01)

- templates: replace reStructedText with reStructuredText

Version 2.0.1 (released 2023-07-26)

- badges: semantic html Fixes

Version 2.0.0 (released 2023-07-19)

- setup: bump pillow minimum version

Version 1.3.0 (released 2023-07-17)

- add template filter for human readable time

Version 1.2.0 (released 2021-02-28)

- remove flask-babelex deprecated dependency
- upgrade invenio-i18n to manage babel globally

Version 1.1.4 (released 2021-10-18)

- Add translation CI
- Add pulled translations
- Move from setup.py to setup.cfg
- Add black

Version 1.1.3 (released 2021-10-18)

- Unpin Flask verison.

Version 1.1.2 (released 2021-07-15)

- Bump Flask minimum version

Version 1.1.1 (released 2021-07-15)

- Adds german translations

Version 1.1.0 (released 2020-12-09)

- Integrates Semantic-UI templates
- Migrates CI to GitHub actions

Version 1.0.3 (released 2020-05-06)

- Deprecated Python versions lower than 3.6.0. Now supporting 3.6.0 and 3.7.0

Version 1.0.2 (released 2019-07-29)

- Adds HTML sanitization Jinja filter.

Version 1.0.1 (released 2018-05-25)

- Fixes issue with badges being cached.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
